#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-Hly6a6kkBoNJeHkKBncVuo
key:                  data-tree-print-0.1.0.2-Hly6a6kkBoNJeHkKBncVuo
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  16c105ca399698e697e82c6950482b04
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-tree-print-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-tree-print
hs-libraries:         HSdata-tree-print-0.1.0.2-Hly6a6kkBoNJeHkKBncVuo
depends:
    base-4.18.2.1 pretty-1.1.3.6 syb-0.7.3-3hnWhpJZuWdE2NXpC0N7hI

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

